# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *

def update_package():
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()

    app_name = control.name
    git_repo = "nicotine-plus/nicotine-plus"
    url_api = f"https://api.github.com/repos/{git_repo}/releases/latest"

    os_arch = f"{control.target_os}-{control.architecture}"
    url_os_dict = {
        'windows-x64': 'windows-x86_64-installer.zip',
        'darwin-arm64': 'macos-arm64-installer.zip',
        'darwin-x64': 'macos-x86_64-installer.zip',
        'debian_base-all' : 'debian-package.zip'
    }

    # Getting latest version information from official sources
    print("API used is: %s" % url_api)
    json_load = wgets(url_api, proxies=proxies, as_json=True)
    
    download_url = None
    for download in json_load["assets"]:
        if download["browser_download_url"].endswith(url_os_dict[os_arch]):
            download_url = download["browser_download_url"]
            version = json_load["tag_name"].replace("v","")
            zip_file = download["name"]
            break

    if download_url is None:
        print(f"No '{url_os_dict[os_arch]}' found in the latest release.")
        return package_updated

    # Downloading latest binaries
    print(f"Latest {app_name} version is: {version}")
    print(f"Download URL is: {download_url}")
    if not isfile(zip_file):
        print(f"Downloading: {zip_file}")
        wget(download_url, zip_file, proxies=proxies)
    else:
        print(f"ZIP file is present: {zip_file}")

    unzip(zip_file, target=basedir)

    # Delete the ZIP file after extraction
    if isfile(zip_file):
        print(f"Deleted the ZIP file: {zip_file}")
        remove_file(zip_file)

    for f in glob.glob('*.msi'):
        if Version(version) < Version(get_version_from_binary(f)):
            remove_file(f)

    control.set_software_version(version)
    control.save_control_to_wapt()

    get_msi_properties